.. 2016-07-31 sonofeft d427df69d88ecd0ebf208bbc76ae65d5f707c5ef
   Maintain spacing of "History" and "GitHub Log" titles

History
=======

GitHub Log
----------

* March 6, 2023
    - (by: sonofeft) 
        - Updating to Python 3.x
        - Dropping support for Python 2.x

* Jul 31, 2016
    - (by: sonofeft) 
        - Fixing path generation for Linux

* Jul 31, 2016
    - (by: sonofeft) 
        - First Whack at setting up project
    - (by: Charlie Taylor) 
        - Initial commit


* Jul 30, 2016
    - (by: sonofeft)
        - First Created ParaSol with PyHatch